==> unify_api-1.1.1%2B1.tar.gz: example_db/lib/ui/common/app_drawer.dart <==
import 'package:example_db/ui/video/screen.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get_it/get_it.dart';

import '../../data/blocs/bloc.dart';
import '../../data/services/database/database.dart';
import '../account/screen.dart';
import '../contacts/screen.dart';
import '../leads/screen.dart';
import '../loans/screen.dart';

class MenuButton extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    if (Scaffold.of(context).hasDrawer) {
      return IconButton(
        icon: Icon(Icons.menu),
        onPressed: () {
          BlocProvider.of<ScaffoldBloc>(context).dispatch(ShowMenu());
        },
      );
    }
    return Container();
  }
}

class AppDrawer extends StatelessWidget {
  const AppDrawer(this.onRoutePress);

  final Function(String) onRoutePress;

  @override
  Widget build(BuildContext context) {
    final _user = AuthBloc.currentUser(context);
    final nav = BlocProvider.of<NavBloc>(context);
    return Drawer(
      child: SingleChildScrollView(
        child: Container(
          child: Column(
            children: <Widget>[
              AccountHeader(onRoutePress: onRoutePress),
              // if (sideMenu) ...[
              //   ListTile(
              //     leading: Icon(Icons.home),
              //     title: Text('Home'),
              //     onTap: () {
              //       onRoutePress('home');
              //     },
              //   ),
              // ],
              ListTile(
                leading: Icon(Icons.folder),
                title: Text('Loans'),
                onTap: () {
                  onRoutePress(LoansScreen.routeName);
                },
              ),
              ListTile(
                leading: Icon(Icons.contacts),
                title: Text('Contacts'),
                onTap: () {
                  onRoutePress(ContactsScreen.routeName);
                },
              ),
              ListTile(
                leading: Icon(Icons.people),
                title: Text('Leads'),
                onTap: () {
                  onRoutePress(LeadsScreen.routeName);
                },
              ),
              ListTile(
                leading: Icon(Icons.flag),
                title: Text('Marketing'),
                onTap: () {},
              ),
              ListTile(
                leading: Icon(Icons.video_library),
                title: Text('Unfiy Video'),
                onTap: () {
                  onRoutePress(VideosScreen.routeName);
                },
              ),
            ],
          ),
        ),
      ),
    );
  }
}

class AccountHeader extends StatelessWidget {
  const AccountHeader({
    Key key,
    @required this.onRoutePress,
  }) : super(key: key);

  final Function(String) onRoutePress;

  @override
  Widget build(BuildContext context) {
    final _user = AuthBloc.currentUser(context);
    final nav = BlocProvider.of<NavBloc>(context);
    return Container(
      child: StreamBuilder<List<User>>(
          stream:
              GetIt.instance<DatabaseService>().watchOtherUsers(_user.userID),
          builder: (context, snapshot) {
            final _users = snapshot.data;
            return UserAccountsDrawerHeader(
              currentAccountPicture: _buildAvatar(_user.profileImage),
              onDetailsPressed: () {
                onRoutePress(AccountScreen.routeName);
              },
              accountName: Text(_user.firstName + ' ' + _user.lastName),
              accountEmail: Text(_user.email),
              decoration: BoxDecoration(
                color: Colors.grey,
                image: kIsWeb
                    ? null
                    : DecorationImage(
                        image: NetworkImage(_user.companyImage),
                        fit: BoxFit.cover,
                        colorFilter: ColorFilter.mode(
                            Colors.black.withOpacity(0.2), BlendMode.dstATop),
                      ),
              ),
              otherAccountsPictures: _users == null
                  ? []
                  : _users
                      .map((u) => InkWell(
                            child: _buildAvatar(u.profileImage),
                            onTap: () {
                              BlocProvider.of<AuthBloc>(context)
                                  .dispatch(SwitchUser(u));
                            },
                          ))
                      .toList(),
            );
          }),
    );
  }

  Widget _buildAvatar(String image) {
    return CircleAvatar(backgroundImage: NetworkImage(image));
  }
}

==> unify_api-1.2.6%2B1.tar.gz: example_db/lib/ui/common/app_drawer.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get_it/get_it.dart';

import '../../data/blocs/bloc.dart';
import '../../data/services/database/database.dart';
import '../account/screen.dart';
import '../contacts/screen.dart';
import '../leads/screen.dart';
import '../loans/screen.dart';
import '../marketing/screen.dart';
import '../video/screen.dart';

class MenuButton extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    if (Scaffold.of(context).hasDrawer) {
      return IconButton(
        icon: Icon(Icons.menu),
        onPressed: () {
          BlocProvider.of<ScaffoldBloc>(context).dispatch(ShowMenu());
        },
      );
    }
    return Container();
  }
}

class AppDrawer extends StatelessWidget {
  const AppDrawer(this.onRoutePress);

  final Function(String) onRoutePress;

  @override
  Widget build(BuildContext context) {
    final nav = BlocProvider.of<NavBloc>(context);
    return Drawer(
      child: SingleChildScrollView(
        child: ListTileTheme(
          selectedColor: Theme.of(context).accentColor,
          child: Column(
            children: <Widget>[
              AccountHeader(onRoutePress: onRoutePress),
              // if (sideMenu) ...[
              //   ListTile(
              //     leading: Icon(Icons.home),
              //     title: Text('Home'),
              //     onTap: () {
              //       onRoutePress('home');
              //     },
              //   ),
              // ],
              ListTile(
                leading: Icon(Icons.folder),
                title: Text('Loans'),
                onTap: () {
                  onRoutePress(LoansScreen.routeName);
                },
              ),
              ListTile(
                leading: Icon(Icons.contacts),
                title: Text('Contacts'),
                onTap: () {
                  onRoutePress(ContactsScreen.routeName);
                },
              ),
              ListTile(
                leading: Icon(Icons.people),
                title: Text('Leads'),
                onTap: () {
                  onRoutePress(LeadsScreen.routeName);
                },
              ),
              ListTile(
                leading: Icon(Icons.flag),
                title: Text('Marketing'),
                onTap: () {
                  onRoutePress(MarketingScreen.routeName);
                },
              ),
              ListTile(
                leading: Icon(Icons.video_library),
                title: Text('Unify Video'),
                onTap: () {
                  onRoutePress(VideosScreen.routeName);
                },
              ),
            ],
          ),
        ),
      ),
    );
  }
}

class AccountHeader extends StatelessWidget {
  const AccountHeader({
    Key key,
    @required this.onRoutePress,
  }) : super(key: key);

  final Function(String) onRoutePress;

  @override
  Widget build(BuildContext context) {
    final _user = AuthBloc.currentUser(context);
    final nav = BlocProvider.of<NavBloc>(context);
    return Container(
      child: StreamBuilder<List<User>>(
          stream:
              GetIt.instance<DatabaseService>().watchOtherUsers(_user.userID),
          builder: (context, snapshot) {
            final _users = snapshot.data;
            return UserAccountsDrawerHeader(
              currentAccountPicture: _buildAvatar(_user.profileImage),
              onDetailsPressed: () {
                onRoutePress(AccountScreen.route);
              },
              accountName: Text(_user.firstName + ' ' + _user.lastName),
              accountEmail: Text(_user.email),
              decoration: BoxDecoration(
                color: Colors.grey,
                image: kIsWeb
                    ? null
                    : DecorationImage(
                        image: NetworkImage(_user.companyImage),
                        fit: BoxFit.cover,
                        colorFilter: ColorFilter.mode(
                            Colors.black.withOpacity(0.2), BlendMode.dstATop),
                      ),
              ),
              otherAccountsPictures: _users == null
                  ? []
                  : _users
                      .map((u) => InkWell(
                            child: _buildAvatar(u.profileImage),
                            onTap: () {
                              BlocProvider.of<AuthBloc>(context)
                                  .dispatch(SwitchUser(u));
                            },
                          ))
                      .toList(),
            );
          }),
    );
  }

  Widget _buildAvatar(String image) {
    return CircleAvatar(backgroundImage: NetworkImage(image));
  }
}
